@@ -11,7 +11,6 @@ from rich.progress import (
     BarColumn,
     DownloadColumn,
     Progress,
-    TaskID,
     TextColumn,
     TimeRemainingColumn,
     TransferSpeedColumn,
@@ -151,7 +150,9 @@ class EncryptedSocketClientTransport(ClientTransport):
         return self._proxy_source
 
     @classmethod
-    def clone(cls, transport: EncryptedSocketClientTransport) -> EncryptedSocketClientTransport:
+    def clone(
+        cls, transport: EncryptedSocketClientTransport
+    ) -> EncryptedSocketClientTransport:
         address = transport.address
         port = transport._port
         auth_provider = transport.auth_provider
@@ -159,8 +160,14 @@ class EncryptedSocketClientTransport(ClientTransport):
         on_pty_data_callback = transport.on_pty_data_callback
         on_pty_closed_callback = transport.on_pty_closed_callback
 
-        return cls(address, port, auth_provider, proxy_target, on_pty_data_callback, on_pty_closed_callback)
-
+        return cls(
+            address,
+            port,
+            auth_provider,
+            proxy_target,
+            on_pty_data_callback,
+            on_pty_closed_callback,
+        )
 
     @staticmethod
     def session_key_message(key_pem: str, aes_key: str) -> SessionKeyMessage:
@@ -374,7 +381,7 @@ class EncryptedSocketClientTransport(ClientTransport):
 
         if self.auth_required and not self.auth_provider:
             self.auth_error = "Auth required and no auth provider set"
-            log.error(self.auth_error)
+            log.warning(self.auth_error)
             await self.disconnect()
             self._connecting = False
             return
@@ -447,11 +454,18 @@ class EncryptedSocketClientTransport(ClientTransport):
 
     async def read_socket_loop(self):
         extra_messages = []
+        timeout = 15
         while self.reader and not self.reader.at_eof():
             try:
-                data = await self.reader.readuntil(self.separator)
+                coro = self.reader.readuntil(self.separator)
+                data = await asyncio.wait_for(coro, timeout=timeout)
+            except TimeoutError as e:
+                log.error(f"Timeout of {timeout}s exceeded for socket read, returning")
+                self._connected = False
+                self.encrypted = False
+                break
             except asyncio.IncompleteReadError as e:
-                log.debug("EOF reached, socket closed")
+                # log.debug("EOF reached, socket closed")
                 self._connected = False
                 self.encrypted = False
                 break
@@ -462,7 +476,7 @@ class EncryptedSocketClientTransport(ClientTransport):
                 break
             except asyncio.LimitOverrunError as e:
                 data = []
-                
+
                 while True:
                     current = await self.reader.read(64000)
                     if current.endswith(self.separator):
@@ -470,7 +484,7 @@ class EncryptedSocketClientTransport(ClientTransport):
                         break
 
                     data.append(current)
-                
+
                 count = re.findall(b"\<\?!!\?\\>", data[-1])
 
                 # split messages
@@ -480,19 +494,21 @@ class EncryptedSocketClientTransport(ClientTransport):
                     # or just remove the last item?
                     extra_messages = list(filter(None, extra_messages))
                     last_data = extra_messages.pop(0)
-                    data.append(last_data+b"<?!!?>")
+                    data.append(last_data + b"<?!!?>")
 
                 data = b"".join(data)
             except Exception as e:
                 print("in read socket loop")
                 print(repr(e))
+                self._connected = False
+                self.encrypted = False
                 break
 
             message = data.rstrip(self.separator)
 
             all_messages = [message, *extra_messages]
             extra_messages = []
-            
+
             for message in all_messages:
                 # ToDo: catch
                 try:
@@ -500,45 +516,40 @@ class EncryptedSocketClientTransport(ClientTransport):
                 except Exception as e:
                     print("can't deserialize in for")
                     print(repr(e))
+                    continue
                 log.debug(f"Received : {type(message).__name__}")
 
                 if self.encrypted:
                     message = message.decrypt(self.aeskey)
 
-                if isinstance(message, PtyMessage):
-                    our_socket = self.writer.get_extra_info("sockname")
-                    await self.on_pty_data_callback(our_socket, message.data)
-                    continue
+                match message:
+                    case PtyMessage():
+                        our_socket = self.writer.get_extra_info("sockname")
+                        await self.on_pty_data_callback(our_socket, message.data)
 
-                if isinstance(message, RpcReplyMessage):
-                    await self.messages.put(message)
-                    continue
+                    case RpcReplyMessage():
+                        await self.messages.put(message)
 
-                if isinstance(message, (ChallengeMessage, AuthReplyMessage)):
-                    await self.authentication_message_handler(message)
-                    continue
+                    case ChallengeMessage() | AuthReplyMessage():
+                        await self.authentication_message_handler(message)
 
-                if isinstance(message, ProxyResponseMessage):
-                    asyncio.create_task(self.forwarding_message_handler(message))
-                    continue
+                    case ProxyResponseMessage():
+                        asyncio.create_task(self.forwarding_message_handler(message))
 
-                if isinstance(message, (RsaPublicKeyMessage, TestMessage)):
-                    await self.encryption_message_handler(message)
-                    continue
+                    case RsaPublicKeyMessage() | TestMessage():
+                        await self.encryption_message_handler(message)
 
-                # This is our test message as we're not encrypted yet
-                # it could be part of the handler above but more clear here
-                if isinstance(message, EncryptedMessage):
-                    await self.encryption_message_handler(message)
-                    continue
+                    # This is our test message as we're not encrypted yet
+                    # it could be part of the handler above but more clear here
+                    case EncryptedMessage():
+                        await self.encryption_message_handler(message)
 
-                if isinstance(message, PtyClosedMessage):
-                    our_socket = self.writer.get_extra_info("sockname")
-                    await self.on_pty_closed_callback(our_socket)
-                    continue
+                    case PtyClosedMessage():
+                        our_socket = self.writer.get_extra_info("sockname")
+                        await self.on_pty_closed_callback(our_socket)
 
-                else:
-                    log.error(f"Unknown message: {message}")
+                    case _:
+                        log.error(f"Unknown message: {message}")
 
         log.debug("Finished read socket loop")
 
@@ -556,12 +567,14 @@ class EncryptedSocketClientTransport(ClientTransport):
         for local_path, remote_path in files:
             eof = False
 
-            log.info(f'Client transport: About to stream file {local_path.name}')
+            log.info(f"Client transport: About to stream file {local_path.name}")
 
             size = local_path.stat().st_size
 
             with self.progress:
-                task_id = self.progress.add_task("download", filename=local_path.name, start=False)
+                task_id = self.progress.add_task(
+                    "download", filename=local_path.name, start=False
+                )
                 self.progress.update(task_id, total=size)
 
                 async with aiofiles.open(local_path, "rb") as f:
@@ -577,7 +590,9 @@ class EncryptedSocketClientTransport(ClientTransport):
 
                         if not data:
                             end = time.time()
-                            log.info(f"Client Transport: Transdfer complete. Elapsed: {end - start}")
+                            log.info(
+                                f"Client Transport: Transdfer complete. Elapsed: {end - start}"
+                            )
                             eof = True
 
                         msg = FileEntryStreamMessage(data, remote_path, eof)
@@ -651,6 +666,7 @@ class EncryptedSocketClientTransport(ClientTransport):
             f"Disconnect called for socket: {sockname}. Total channels before: {self.channels}"
         )
         self.channels -= 1
+        # this is dodgey, -1 is True
         if self.channels:
             return
 
